Module exit

Module exit 

Functions

abort
Exits the VM with an Abort OUT action and code 0.
abort_with_code
Exits the VM with an Abort OUT action and a specific code.
abort_with_code_and_message
Aborts the program with a code and a message.
debug_print
Prints a message using OutBAction::DebugPrint. It transmits bytes of a message through several VMExists and, with such, it is slower than print_output_with_host_print.
write_abort
This function exists to give the guest more manual control over the abort sequence. For example, in hyperlight_guest_bin’s panic handler, we have a message of unknown length that we want to stream to the host, which requires sending the message in chunks