pub fn debug_print(msg: &str)Expand description
Prints a message using OutBAction::DebugPrint. It transmits bytes of a message
through several VMExists and, with such, it is slower than
print_output_with_host_print.
This function should be used in debug mode only. This function does not require memory to be setup to be used.