write_abort

Function write_abort 

pub fn write_abort(code: &[u8])
This function exists to give the guest more manual control over the abort sequence. For example, in hyperlight_guest_bin’s panic handler, we have a message of unknown length that we want to stream to the host, which requires sending the message in chunks