Constants
- MAIN_
STACK_ LIMIT_ GVA - MAIN_
STACK_ TOP_ GVA - Note that the x86-64 ELF psABI requires that the stack be 16-byte aligned before a call instruction; we use the aligned version here, even though this requires adjusting the pointer by 8 bytes when entering the guest without a call instruction to push a return address.