Prints a message using OutBAction::DebugPrint. It transmits bytes of a message
through several VMExists and, with such, it is slower than
print_output_with_host_print.
This function exists to give the guest more manual control
over the abort sequence. For example, in hyperlight_guest_bin’s panic handler,
we have a message of unknown length that we want to stream
to the host, which requires sending the message in chunks